package org.ow2.petals.admin.api.artifact.lifecycle;

import java.net.URL;

import org.ow2.petals.admin.api.exception.ArtifactAdministrationException;
import org.ow2.petals.admin.api.exception.ArtifactDeployedException;
import org.ow2.petals.admin.api.exception.ArtifactNotDeployedException;
import org.ow2.petals.admin.api.exception.ArtifactNotFoundException;
import org.ow2.petals.admin.api.exception.ArtifactStartedException;
import org.ow2.petals.admin.api.exception.ArtifactStoppedException;

public interface ArtifactLifecycle {

    /**
     * Install/deploy the artifact
     * 
     * @throws ArtifactDeployedEXception
     *             The artifact is already deployed.
     * @throws ArtifactAdministrationException
     *             An error occurs during the artifact deployment.
     */
    public void deploy(URL artifactUrl) throws ArtifactDeployedException,
            ArtifactAdministrationException;

    /**
     * Start the artifact
     * 
     * @throws ArtifactStartedException
     *             The artifact is already started
     * @throws ArtifactNotDeployedException
     *             The artifact is not deployed
     * @throws ArtifactNotFoundException
     *             The artifact can not be found
     * @throws ArtifactAdministrationException
     *             An error occurs during the artifact start.
     */
    public void start() throws ArtifactStartedException, ArtifactNotDeployedException,
            ArtifactNotFoundException, ArtifactAdministrationException;

    /**
     * Stop the artifact
     * 
     * @throws ArtifactStoppedException
     *             The artifact is already stopped
     * @throws ArtifactNotDeployedException
     *             The artifact is not deployed
     * @throws ArtifactNotFoundException
     *             The artifact can not be found
     * @throws ArtifactAdministrationException
     *             An error occurs during the artifact stop.
     * 
     */
    public void stop() throws ArtifactStoppedException, ArtifactNotDeployedException,
            ArtifactNotFoundException, ArtifactAdministrationException;

    /**
     * Undeploy the artifact
     * 
     * @throws ArtifactStartedException
     *             The artifact is started
     * @throws ArtifactNotFoundException
     *             The artifact can not be found
     * @throws ArtifactAdministrationException
     *             An error occurs during the artifact stop.
     */
    public void undeploy() throws ArtifactStartedException, ArtifactNotFoundException,
            ArtifactAdministrationException;
    
    /**
     * Update the state of the artifact (if there is one)
     */
    public void updateState() throws ArtifactAdministrationException;
}
