/****************************************************************************
 *
 *  Copyright (c) 2012, EBM WebSourcing
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

package org.ow2.petals.admin.api.exception;

/**
 * Exception thrown when an artifact can not be found.
 * 
 * @author Christophe DENEUX - Linagora
 */
public class ArtifactNotFoundException extends ArtifactAdministrationException {

    private static final long serialVersionUID = 4339577587430827255L;

    /**
     * The artifact type.
     */
    private final String type;
    
    /**
     * The artifact name.
     */
    private final String name;

    public ArtifactNotFoundException(final String type, final String name) {
        super(String.format("Cannot find the artifact [type [%s], name [%s]", type == null ? "null"
                : type, name));
        this.type = type;
        this.name = name;
    }

    /**
     * @return The artifact type
     */
    public String getType() {
        return this.type;
    }

    /**
     * @return The artifact name
     */
    public String getName() {
        return this.name;
    }
}
