/****************************************************************************
 *
 *  Copyright (C) 2012, EBM WebSourcing
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

package org.ow2.petals.admin;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.ow2.petals.admin.api.ArtifactAdministration;
import org.ow2.petals.admin.api.artifact.Artifact;
import org.ow2.petals.admin.api.artifact.lifecycle.ArtifactLifecycle;
import org.ow2.petals.admin.api.artifact.lifecycle.ArtifactLifecycleFactory;
import org.ow2.petals.admin.api.exception.ArtifactAdministrationException;
import org.ow2.petals.admin.api.exception.ArtifactNotFoundException;
import org.ow2.petals.admin.api.exception.ArtifactTypeIsNeededException;

/**
 * 
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 * 
 */
public class ArtifactAdministrationMock extends ArtifactAdministration {

    @Override
    public void stopAndUndeployAllArtifacts() throws ArtifactAdministrationException {
        Artifact[] artifacts = RegistryMock.getInstance().list();
        for (Artifact a : artifacts) {
            ArtifactLifecycle aLifecycle = ArtifactLifecycleFactory.newInstance(a);
            aLifecycle.stop();
            aLifecycle.undeploy();
        }
    }

    @Override
    public List<Artifact> listArtifacts() throws ArtifactAdministrationException {
        return Arrays.asList(RegistryMock.getInstance().list());
    }

    @Override
    public Artifact getArtifact(String type, String name) throws ArtifactAdministrationException {
        assert name != null;

        Artifact[] artifacts = RegistryMock.getInstance().list();
        final List<Artifact> artifactsMatchingName = new ArrayList<Artifact>();
        if (type != null) {
            for (Artifact artifact : artifacts) {
                if (artifact.getType().equals(type) && artifact.getName().equals(name)) {
                    artifactsMatchingName.add(artifact);
                }
            }
        } else {
            for (Artifact artifact : artifacts) {
                if (artifact.getName().equals(name)) {
                    artifactsMatchingName.add(artifact);
                }
            }
        }
        if (artifactsMatchingName.size() == 0) {
            throw new ArtifactNotFoundException(type, name);
        } else if (artifactsMatchingName.size() > 1) {
            throw new ArtifactTypeIsNeededException(name);
        } else {
            return artifactsMatchingName.get(0);
        }
    }

}
