/****************************************************************************
 *
 *  Copyright (C) 2012, EBM WebSourcing
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

package org.ow2.petals.admin;

import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Properties;

import org.ow2.petals.admin.api.ContainerAdministration;
import org.ow2.petals.admin.api.artifact.Logger;
import org.ow2.petals.admin.api.exception.ContainerAdministrationException;
import org.ow2.petals.admin.api.exception.InvalidLogLevelException;
import org.ow2.petals.admin.api.exception.LoggerNotFoundException;
import org.ow2.petals.admin.topology.Domain;

/**
 * 
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 * 
 */
public class ContainerAdministrationMock implements ContainerAdministration {

    public static final String SYSTEM_INFO = "Petals JBI Container 3.3-SNAPSHOT"
            + "Java(TM) SE Runtime Environment 20.4-b02 Sun Microsystems Inc."
            + "Linux 3.3.1-1-ARCH amd64";

    public static final String INVALID_LOGGER_NAME = "invalid.logger";

    public static final String INVALID_LOG_LEVEL = "INVALID_LEVEL";

    public static final String ROOT_LOGGER_NAME = "";

    public static final String ROOT_LEVEL = "FINEST";

    public static final String LOGGER1_LOGGER_NAME = "logger.1";

    public static final String LOGGER1_LEVEL = "FINEST";

    public static final String LOGGER2_LOGGER_NAME = "logger.2";

    public static final String LOGGER2_LEVEL = "INFO";

    /**
     * Name of an host generating an error as 'host unknown'.
     */
    public static final String UNKNOWN_HOST = "unknown";

    private final Map<String, String> loggers = new HashMap<String, String>();

    public ContainerAdministrationMock() {
        this.loggers.put(ROOT_LOGGER_NAME, ROOT_LEVEL);
        this.loggers.put(LOGGER1_LOGGER_NAME, LOGGER1_LEVEL);
        this.loggers.put(LOGGER2_LOGGER_NAME, LOGGER2_LEVEL);
    }

    @Override
    public void connect(String host, int port, String user, String password)
            throws ContainerAdministrationException {
        if (host.equals(UNKNOWN_HOST)) {
            throw new ContainerAdministrationException("Unknown Host");
        }

    }

    @Override
    public void disconnect() throws ContainerAdministrationException {
        // TODO Auto-generated method stub

    }

    @Override
    public String getSystemInfo() throws ContainerAdministrationException {
        return SYSTEM_INFO;
    }

    @Override
    public void stopContainer() throws ContainerAdministrationException {
        // TODO Auto-generated method stub

    }

    @Override
    public void shutdownContainer() throws ContainerAdministrationException {
        // TODO Auto-generated method stub

    }

    @Override
    public Domain getTopology() throws ContainerAdministrationException {
        // TODO Auto-generated method stub
        return null;
    }

    @Override
    public Properties getServerProperties() throws ContainerAdministrationException {
        // TODO Auto-generated method stub
        return null;
    }

    /**
     * <p>
     * The logger name 'invalid.logger' is associated to a logger that does not
     * exist.
     * </p>
     * <p>
     * The level 'INVALID_LEVEL' is associated to an invalid log level.
     * </p>
     */
    @Override
    public void changeLoggerLevel(String loggerName, String loggerLevel)
            throws LoggerNotFoundException, InvalidLogLevelException,
            ContainerAdministrationException {
        if (ContainerAdministrationMock.INVALID_LOGGER_NAME.equals(loggerName)) {
            throw new LoggerNotFoundException(loggerName);
        }

        if (ContainerAdministrationMock.INVALID_LOG_LEVEL.equals(loggerLevel)) {
            throw new InvalidLogLevelException(loggerLevel);
        }

        this.loggers.put(loggerName, loggerLevel);
    }

    @Override
    public List<Logger> getLoggers() throws ContainerAdministrationException {
        final List<Logger> loggers = new LinkedList<Logger>();
        for (final Entry<String, String> logger : this.loggers.entrySet()) {
            loggers.add(new Logger(logger.getKey(), logger.getValue()));
        }
        return loggers;
    }

}
