/****************************************************************************
 *
 *  Copyright (c) 2012, EBM WebSourcing
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

package org.ow2.petals.admin;

import java.net.URL;

import org.ow2.petals.admin.api.artifact.ArtifactState.State;
import org.ow2.petals.admin.api.artifact.ServiceAssembly;
import org.ow2.petals.admin.api.artifact.lifecycle.ServiceAssemblyLifecycle;
import org.ow2.petals.admin.api.exception.ArtifactAdministrationException;

/**
 * 
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 * 
 */
public class ServiceAssemblyLifecycleMock extends ServiceAssemblyLifecycle {

    public ServiceAssemblyLifecycleMock(ServiceAssembly sa) {
        super(sa);
    }

    @Override
    public void deploy(URL artifactUrl) throws ArtifactAdministrationException {
        RegistryMock.getInstance().add(getServiceAssembly());
    }

    @Override
    public void start() throws ArtifactAdministrationException {
        ServiceAssembly found = (ServiceAssembly) RegistryMock.getInstance().get(getServiceAssembly());
        if (found == null)
            throw new ArtifactAdministrationException(
                    "Artifact not found in registry. Can not update state");
        found.setState(State.STARTED);

    }

    @Override
    public void stop() throws ArtifactAdministrationException {
        ServiceAssembly found = (ServiceAssembly) RegistryMock.getInstance().get(getServiceAssembly());
        if (found == null)
            throw new ArtifactAdministrationException(
                    "Artifact not found in registry. Can not update state");
        found.setState(State.STOPPED);
    }

    @Override
    public void undeploy() throws ArtifactAdministrationException {
        RegistryMock.getInstance().remove(getServiceAssembly());
    }

    @Override
    public void updateState() throws ArtifactAdministrationException {
        ServiceAssembly found = (ServiceAssembly) RegistryMock.getInstance().get(
                getServiceAssembly());
        if (found == null)
            throw new ArtifactAdministrationException(
                    "Artifact not found in registry. Can not update state");
        getServiceAssembly().setState(found.getState());
    }

}
