
package org.ow2.petals.admin.api.artifact;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.net.URL;
import java.util.Properties;
import java.util.zip.ZipEntry;
import java.util.zip.ZipException;
import java.util.zip.ZipOutputStream;

import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

public class ArtifactUtilsTest {

    protected final static String BC_JBI = "bc.jbi.xml";

    protected final static String SE_JBI = "se.jbi.xml";

    protected final static String SA_JBI = "sa.jbi.xml";

    protected final static String SL_JBI = "sl.jbi.xml";

    @Test
    public void createArtifactTest() throws ArtifactException, IOException {

        Artifact artifact = ArtifactUtils.createArtifact(createArtifactURL(BC_JBI));
        assertTrue(artifact instanceof Component);
        assertTrue(artifact instanceof ArtifactState);

        artifact = ArtifactUtils.createArtifact(createArtifactURL(SE_JBI));
        assertTrue(artifact instanceof Component);
        assertTrue(artifact instanceof ArtifactState);

        artifact = ArtifactUtils.createArtifact(createArtifactURL(SA_JBI));
        assertTrue(artifact instanceof ServiceAssembly);
        assertTrue(artifact instanceof ArtifactState);

        artifact = ArtifactUtils.createArtifact(createArtifactURL(SL_JBI));
        assertTrue(artifact instanceof SharedLibrary);
    }

    @Test
    public void createComponentWithGivenPropertiesTest() throws ArtifactException, IOException {
        Properties expectedProperties = new Properties();
        expectedProperties.put("key1", "value1");
        expectedProperties.put("key2", "value2");

        Component component = (Component) ArtifactUtils.createArtifact(createArtifactURL(BC_JBI),
                expectedProperties);
        assertEquals(expectedProperties, component.getParameters());

        URL propertiesFile = Thread.currentThread().getContextClassLoader()
                .getResource("test.properties");
        component = (Component) ArtifactUtils.createArtifact(createArtifactURL(BC_JBI),
                propertiesFile);
        assertEquals(expectedProperties, component.getParameters());
    }

    /**
     * Create jbi zip with the specifed jbi descriptor
     * 
     * @param jbiFile
     * @return url of the jbi zip
     * @throws ZipException
     * @throws IOException
     */
    public static URL createArtifactURL(String jbiFile) throws ZipException, IOException {
        byte[] buf = new byte[1024];
        final URL jbiURL = Thread.currentThread().getContextClassLoader().getResource(jbiFile);
        File zip = File.createTempFile("jbi", ".zip");
        zip.deleteOnExit();
        ZipOutputStream zos = new ZipOutputStream(new FileOutputStream(zip));
        // copy file content into zipfile
        FileInputStream fis = new FileInputStream(new File(jbiURL.getFile()));
        zos.putNextEntry(new ZipEntry("META-INF/jbi.xml"));
        int len = 0;
        while ((len = fis.read(buf)) > 0) {
            zos.write(buf, 0, len);
        }
        zos.closeEntry();
        fis.close();
        zos.close();
        return zip.toURI().toURL();
    }
}
