/****************************************************************************
 *
 *  Copyright (c) 2012, EBM WebSourcing
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

package org.ow2.petals.admin.api.artifact.lifecycle;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;

import org.junit.Test;
import org.ow2.petals.admin.ArtifactLifecycleFactoryMock;
import org.ow2.petals.admin.ComponentLifecycleMock;
import org.ow2.petals.admin.ServiceAssemblyLifecycleMock;
import org.ow2.petals.admin.SharedLibraryLifecycleMock;
import org.ow2.petals.admin.api.AdminFactory;
import org.ow2.petals.admin.api.artifact.Artifact;
import org.ow2.petals.admin.api.artifact.Component;
import org.ow2.petals.admin.api.artifact.Component.ComponentType;
import org.ow2.petals.admin.api.artifact.ServiceAssembly;
import org.ow2.petals.admin.api.artifact.ServiceUnit;
import org.ow2.petals.admin.api.artifact.SharedLibrary;

import com.ebmwebsourcing.easycommons.lang.UncheckedException;

/**
 * 
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 * 
 */
public class ArtifactLifecycleFactoryTest {

    @Test
    public void createArtifactLifecycleTest() {
        System.setProperty(ArtifactLifecycleFactory.FACTORY_PROPERTY_KEY,
                ArtifactLifecycleFactoryMock.class.getName());
        Component bc = new Component("petals-bc-test", ComponentType.BC);
        Component se = new Component("petals-se-test", ComponentType.SE);
        ServiceAssembly sa = new ServiceAssembly("sa-test");
        SharedLibrary sl = new SharedLibrary("sl-test");

        ArtifactLifecycle artifactLifecycle = ArtifactLifecycleFactory.newInstance(bc);
        assertTrue(artifactLifecycle instanceof ComponentLifecycleMock);

        artifactLifecycle = ArtifactLifecycleFactory.newInstance(se);
        assertTrue(artifactLifecycle instanceof ComponentLifecycleMock);

        artifactLifecycle = ArtifactLifecycleFactory.newInstance(sa);
        assertTrue(artifactLifecycle instanceof ServiceAssemblyLifecycleMock);

        artifactLifecycle = ArtifactLifecycleFactory.newInstance(sl);
        assertTrue(artifactLifecycle instanceof SharedLibraryLifecycleMock);

        System.getProperties().remove(AdminFactory.FACTORY_PROPERTY_KEY);
    }

    @Test
    public void createArtifactLifecycleWithUnknowArtifactTest() {
        UncheckedException e = null;
        ArtifactLifecycle artifactLifecycle = null;
        Artifact[] artifacts = new Artifact[2];
        artifacts[0] = null;
        artifacts[1] = new ServiceUnit("test", "petals-bc-test");

        for (int i = 0; i < artifacts.length; i++) {
            try {
                artifactLifecycle = ArtifactLifecycleFactory.newInstance(artifacts[i]);
            } catch (UncheckedException ex) {
                e = ex;
            }
            assertNull(artifactLifecycle);
            assertNotNull(e);
            assertEquals("Unknow artifact type", e.getMessage());
        }
    }
}
